@@ -143,4 +143,8 @@ def cmd(command , redirect=True):
 def onehot(data, nb_classes):
     """Convert an iterable of indices to one-hot encoded labels."""
     targets = np.array(data).reshape(-1)
-    return np.eye(nb_classes)[targets]
\ No newline at end of file
+    return np.eye(nb_classes)[targets]
+    
+    
+def exe(fname):
+    cmd('pyinstaller --onefile ' + fname , False)    
\ No newline at end of file
