@@ -73,4 +73,47 @@ def cer_list(ref_list , hyp_list):
     x=[]
     for i in range(len(ref_list)):
        x.append(cer(ref_list[i] , hyp_list[i]))
-    return np.mean(x)    
\ No newline at end of file
+    return np.mean(x)    
+    
+    
+def DER(ref_list , res_list , file_dur=-1 , sr=8000):
+    """ input--> [ [st1,en1] , [st2 , en2] , ....   ]
+        just for speech parts
+        Output--> Miss , FA , DER , miss_points, fa_points
+    """        
+    
+    if (file_dur==-1):
+        file_dur = max(ref_list[-1][1] , res_list[-1][1])
+    
+    ref = np.zeros((int(file_dur*sr)))
+    
+    for a,b in ref_list:
+        ref[int(sr * a) : int(sr*b)]=1
+              
+    res = np.zeros((int(file_dur*sr)))
+    
+    for a,b in res_list:
+        res[int(sr * a) : int(sr*b)]=1
+     
+    
+    _miss_points=[]
+    _y=np.where(ref==1)[0] 
+    for i in _y:
+        if (res[i]==0):
+            _miss_points.append(i)
+    x = len(_miss_points)
+    miss = x / file_dur 
+    
+
+    _fa_points=[]
+    _y=np.where(res==1)[0] 
+    for i in _y:
+        if (ref[i]==0):
+            _fa_points.append(i)
+    x1 = len(_fa_points)
+    fa = x1 / file_dur 
+    
+    _der =(x+x1)/file_dur
+    
+
+    return (miss , fa ,_der ,_miss_points,_fa_points)
\ No newline at end of file
