@@ -68,15 +68,29 @@ def _energy_activity(loge, ratio=0.4):   ##########0.9
 def filter_sig(isig , wav , sr):
     try:
       w=[]
+      wn=[]
+      wn.append(wav[0 : int(isig[0][1]*sr)])
       for i , [_,a,b,_] in enumerate(isig): 
+          
           w.append(wav[int(a*sr) : int(b*sr)])
-      return (np.concatenate(w)) 
+          try:
+            wn.append(wav[ int(isig[i][2]*sr) :  int(isig[i+1][1]*sr)])
+          except:
+            wn.append(wav[int(isig[i][2]*sr) : len(wav)])          
+          
+      return (np.concatenate(w),np.concatenate(wn)) 
     except:
       w=[]
+      wn=[]
+      wn.append(wav[0 : int(isig[0][1]*sr)])
       for i , [_,a,b,_,_] in enumerate(isig): 
           w.append(wav[int(a*sr) : int(b*sr)])
-      return (np.concatenate(w)) 
-      
+          try:
+            wn.append(wav[ int(isig[i][2]*sr) :  int(isig[i+1][1]*sr)])
+          except:
+            wn.append(wav[int(isig[i][2]*sr) : len(wav)])          
+          
+      return (np.concatenate(w),np.concatenate(wn)) 
       
 def filter_output(isig , max_silence=1 ,ignore_small_speech_segments=0.5 , max_speech_len=15,split_speech_bigger_than=20):
 
@@ -390,7 +404,7 @@ class Segmenter:
            return   [[lab, start_sec + start * .02, start_sec + stop * .02 , (stop-start) * .02] for lab, start, stop in lseg if (lab=='speech')]   
 
 
-    def __call__(self, medianame, start_sec=None, stop_sec=None):
+    def __call__(self, medianame, input_type='file',start_sec=None, stop_sec=None):
         """
         Return segmentation of a given file
                 * convert file to wav 16k mono with ffmpeg
@@ -403,7 +417,9 @@ class Segmenter:
         * stop_sec (seconds): sound stream after stop_sec won't be processed
         """
         
-        mspec, loge, difflen , me = media2feats(medianame, self.sample_rate)
+        
+        mspec, loge, difflen , me = media2feats(medianame, input_type ,self.sample_rate)
+        
         if start_sec is None:
             start_sec = 0
         # do segmentation   
