@@ -60,7 +60,7 @@ def _energy_activity(loge, ratio=0.4):   ##########0.9
 #exp(150, cost0=-5)
 
 
-def filter_sig(isig , wav , sr):
+def filter_sig1(isig , wav , sr):
     try:
       w=[]
       for i , [_,a,b,_] in enumerate(isig): 
@@ -72,7 +72,34 @@ def filter_sig(isig , wav , sr):
           w.append(wav[int(a*sr) : int(b*sr)])
       return (np.concatenate(w)) 
       
-      
+
+def filter_sig(isig , wav , sr):
+    try:
+      w=[]
+      wn=[]
+      wn.append(wav[0 : int(isig[0][1]*sr)])
+      for i , [_,a,b,_] in enumerate(isig): 
+          
+          w.append(wav[int(a*sr) : int(b*sr)])
+          try:
+            wn.append(wav[ int(isig[i][2]*sr) :  int(isig[i+1][1]*sr)])
+          except:
+            wn.append(wav[int(isig[i][2]*sr) : len(wav)])          
+          
+      return (np.concatenate(w),np.concatenate(wn)) 
+    except:
+      w=[]
+      wn=[]
+      wn.append(wav[0 : int(isig[0][1]*sr)])
+      for i , [_,a,b,_,_] in enumerate(isig): 
+          w.append(wav[int(a*sr) : int(b*sr)])
+          try:
+            wn.append(wav[ int(isig[i][2]*sr) :  int(isig[i+1][1]*sr)])
+          except:
+            wn.append(wav[int(isig[i][2]*sr) : len(wav)])          
+          
+      return (np.concatenate(w),np.concatenate(wn)) 
+            
 def filter_output(isig , max_silence=1 ,ignore_small_speech_segments=0.5 , max_speech_len=15,split_speech_bigger_than=20):
 
    if (len(isig)==0):
@@ -140,7 +167,8 @@ def filter_output(isig , max_silence=1 ,ignore_small_speech_segments=0.5 , max_s
    for i,(a,b,c,d,e) in enumerate(isign):
       if (e==-1):
           break 
-      _addlen = min(e , 1) / 2      #حداکثر نیم ثانیه به انتهای سگمنت افزوده میشود
+      # _addlen = min(e , 1) / 2      #حداکثر نیم ثانیه به انتهای سگمنت افزوده میشود
+      _addlen = 0
       isign[i] = [a,b,c+_addlen,d+_addlen,e-_addlen]
     
    return(isign) 
@@ -437,7 +465,8 @@ class Segmenter:
         
         isii = self.segment_feats(mspec, loge, start_sec)
 
-        nmfcc = filter_fea(isii , mspec.squeeze(),self.sample_rate , self.max_time)
+        # nmfcc = filter_fea(isii , mspec.squeeze(),self.sample_rate , self.max_time)
+        nmfcc = mspec.squeeze()
         
         return isii,me ,nmfcc
 
