@@ -44,4 +44,23 @@ def change_wallpaper():
        open('temp.jpg', 'wb').write(r.content)   
        import ctypes
        ctypes.windll.user32.SystemParametersInfoW(20, 0, os.path.abspath('temp.jpg'), 3)
-       os.system('del %s' %('temp.jpg'))   
\ No newline at end of file
+       os.system('del %s' %('temp.jpg'))   
+       
+       
+def links(url , filter_text=None):
+    d = dl(url)
+    x=[]
+    idx=0
+    while(idx>=0):
+      try:  
+       idx = d.index("href=" , idx+1)
+       idy = d.index("\"" , idx+7)
+       m = d[idx+6:idy]
+       if (filter_text!=None):
+           if (filter_text in m):
+                x.append(m)
+       else:
+            x.append(m)        
+      except:
+        break
+    return(x)    
\ No newline at end of file
